@@ -76,6 +76,8 @@ class EnviarPedido(Enviar):
 
             shipping_type=TipoEnvio(envio.codigo).valor,
             shipping_cost=self.formatador.formata_decimal(self.valor_envio),
+            extra_amount=self.formatador.formata_decimal(self.pedido.valor_desconto),
+            shipping_address_street=unicode(self.pedido.endereco_entrega.endereco),
             shipping_address_street=unicode(self.pedido.endereco_entrega.endereco[:80]),
             shipping_address_number=self.pedido.endereco_entrega.numero,
             shipping_address_complement=unicode(self.pedido.endereco_entrega.complemento[:40]),
@@ -111,10 +113,13 @@ class EnviarPedido(Enviar):
             return {"content": {"url": url}, "status": 200, "reenviar": False}
         mensagem = []
         if "errors" in retorno:
-            if type(retorno["errors"]) is list:
-                for erro in retorno["errors"]:
-                    mensagem.append("{} - {}".format(erro["error"]["code"], erro["error"]["message"]))
-            else:
-                mensagem.append("{} - {}".format(retorno["errors"]["code"], retorno["errors"]["message"]))
+
+            # if type(retorno["errors"]) is list:
+            #     for erro in retorno["errors"]:
+            #         mensagem.append("{} - {}".format(erro["error"]["code"], erro["error"]["message"]))
+            # else:
+            #     mensagem.append("{} - {}".format(retorno["errors"]["code"], retorno["errors"]["message"]))
+
+            raise Exception(str(retorno))
 
         return {"content": {"mensagem": ", ".join(mensagem)}, "status": resposta.status_code, "reenviar": False}
